<?php
/** WP Frontpage News Pro Add-on main class **/

//TODO: check if free (main) plugin is installed, generate installation error otherwise.

class wpcuWPFnProPlugin extends YD_Plugin {
	
	/** Drop-down menu values **/
	private $_autoanim_trans_values = array(
			'Fade',
			'Slide'
			//'Scroll to left',
			//'Scroll to right',
			//'Scroll to top',
			//'Scroll to bottom'
	);
	
	/** 
	 * Constructor
	 * 
	 */
	public function __construct( $opts ) {

		parent::YD_Plugin( $opts );
		$this->form_blocks = $opts['form_blocks']; // YD Legacy (was to avoid "backlinkware")
		add_theme_support( 'post-formats', array( 'aside', 'gallery' ,'link' , 'image', 'quote', 'status', 'video', 'audio', 'chat') );
		
		if( is_admin() ) {
			
			/** our own filter and actions to plug the pro features into the free plugin **/
			add_filter( 'wpcufpn_src_type', array( $this, 'srcTypeFilter' ) );
			add_action( 'wpcufpn_source_category_add_fields', array( $this, 'displayContentSourceCategoryTabAddFields' ) );
			//add_action( 'wpcufpn_displayandtheme_add_fields', array( $this, 'displayNumberOfLinesField' ) );
			add_action( 'wpcufpn_displaytheme_col1_add_fields', array( $this, 'displayDisplayThemeCol1AddFields' ) );
			add_action( 'wpcufpn_displayimagesource_crop_add_fields', array( $this, 'displayImageSourceCropAddFields' ) );
			add_action( 'wpcufpn_displayadvanced_add_fields', array( $this, 'displayAdvancedAddFields' ) );
			add_action( 'wpcufpn_display_about', array( $this, 'displayAbout' ) );
			
			add_filter( 'wpcufpn_themedirs', array( $this, 'themeDirsFilter' ) );
			
			/** Load calendar ui **/
			add_action('admin_enqueue_scripts', array( $this, 'loadAdminScripts' ) );
			
		} else {
			
			/** front-end display **/
			//add_filter( 'wpcufpn_front_display', array( $this, 'displayFrontAdditionalSources' ), 10, 2 );
			add_filter( 'wpcufpn_src_category_args', array( $this, 'wpcufpn_src_category_argsFilter' ) );
		}
	}
	
	
	
	/**
	 * Loads js/ajax scripts for admin back-office
	 *
	 */
	public function loadAdminScripts( $hook ) {
		
		
		/** Only load on post edit admin page **/
		if( 'post.php' != $hook && 'post-new.php' != $hook )
			return $hook;
		
		if( wpcuWPFnPlugin::CUSTOM_POST_NEWS_WIDGET_NAME != get_post_type() )
			return $hook;
		
		wp_enqueue_script('jquery-ui-datepicker');

		/* already loaded by free plugin
		
		wp_deregister_script('jquery');
		
		wp_register_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/1.9.0/jquery.min.js", null, "1.9.0");
		wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.2/jquery-ui.min.js", "jquery", "1.10.2");
		
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-ui');
	
		*/
		/*		
		wp_enqueue_script(
			'jquery-ui',
			'http://code.jquery.com/ui/1.9.1/jquery-ui.js',
			array( 'jquery' ),
			'1.0',
			true
		);
		*/
		
		/** choose right language for datepicker js, if available **/
		$lang = WPLANG?str_replace('_','-',WPLANG):'en-us';
		$shortlang = preg_replace( '/\-.*$/', '', $lang );
		$dir = dirname( plugin_dir_path( __FILE__ ) );
		
		/** if the right language file is not present, this will default to already loaded jquery-ui **/
		$file = 'js/jquery.ui.datepicker-' . $shortlang . '.js'; 
		if( file_exists( $dir . '/' . $file ) ) {
			wp_enqueue_script(
				'datepicker-lang',
				plugins_url( $file, dirname( __FILE__ ) ),
				array( 'jquery', 'jquery-ui' ),
				'1.0',
				true
			);
		}

		/** if the right language file is not present, this will default to already loaded jquery-ui **/
		$file = 'js/date-' . $lang . '.js';
		if( file_exists( $dir . '/' . $file ) ) {
			wp_enqueue_script(
					'date-js',
					plugins_url( $file, dirname( __FILE__ ) ),
					array( 'jquery', 'jquery-ui' ),
					'1.0',
					true
			);
		}
	}
	
	/**
	 * Adds pro tabs to the src_type tabbed menu
	 * 
	 * @param array $tabs	array of tab menu generation data
	 * @return array $tabs
	 */
	public function srcTypeFilter( $tabs ) {
		$mytabs = array(
			'tab-1-3' => array(
				'id'	=> 'tab-src_tags',
				'name'	=> __( 'Tags', 'wpcufpn' ),
				'value'		=> 'src_tags',
				'method'	=> array( $this, 'displayContentSourceTagsTab' )
			)
		);
		$tabs = array_merge( $tabs, $mytabs );
		return $tabs;
	}
	
	/**
	 * Adds list of pro theme directories
	 * 
	 * @param array $dirs	free plugin list of theme dirs
	 * @return array		complete list of theme dirs merges with pro
	 */
	public function themeDirsFilter( $idirs=array() ) {
		
		$theme_root = dirname( dirname( __FILE__ ) ) . '/themes';
		//echo 'pro theme dir: ' . $theme_root . '<br/>';	//Debug

		$dirs = @ scandir( $theme_root );
		foreach ( $dirs as $k=>$v ) {
			if( ! is_dir( $theme_root . '/' . $dir ) || $dir[0] == '.' || $dir == 'CVS' ) {
				unset( $dirs[$k] );
			} else {
				$dirs[$k] = array(
					'path' => $theme_root . '/' . $v,
					'url' => plugins_url( 'themes/' . $v, dirname( __FILE__ ) )
				);
			}
		}
		
		$idirs = array_merge( $idirs, $dirs );
		
		return (array)$idirs;
	}
	
	/**
	 * Content source tab for tags
	 *
	 */
	public function displayContentSourceTagsTab() {
		echo '<ul class="fields">';
		
		echo '<li class="field">';
		echo '<ul>';
		
		
		/*
		foreach ($tags as $tag){
			
			echo '<li><input id="'.$tag->slug.'" type="checkbox" name="wpcufpn_source_tags[]" value="'.$tag->term_id.'" />' .
				'<label for="'.$tag->slug.'" class="post_cb">'.$tag->name.'</li>';
			
		}	
		*/
		
		global $post;
		$checked = array(); 
		$settings = get_post_meta( $post->ID, '_wpcufpn_settings', true );
		if( empty( $settings ) )
			$settings = $this->_field_defaults;
		
		if( !isset($settings['source_tags']) || empty($settings['source_tags']) || !$settings['source_tags'] )
			$settings['source_tags'] = array( '_all' );
		
		foreach( $settings['source_tags'] as $tag ) {
			$source_tag_checked[$tag] = ' checked="checked"';
		};
		
		
		echo '<li><input id="tags_all" type="checkbox" name="wpcufpn_source_tags[]" value="_all" ' . $source_tag_checked['_all'] . ' />' .
				'<label for="tags_all" class="post_cb">All tags</li>';
		
		
		$tags = get_tags();		
		foreach ($tags as $tag){
			echo '<li><input id="ccb_' . $tag->term_id . '" type="checkbox" name="wpcufpn_source_tags[]" value="' .
				$tag->term_id . '" ' . $source_tag_checked[$tag->term_id] . ' class="tag_cb" />';
			echo '<label for="ccb_' . $tag->term_id . '" class="post_cb">' . $tag->name . '</label></li>';
		}


				
		echo '</ul>';
		
		echo '</li>';	//field
		
		echo '</ul>';	//fields
	}
	
	/**
	 * Adds fields of the pro plugin to the content_source:category admin settings tab
	 * 
	 */
	public function displayContentSourceCategoryTabAddFields( $settings ) {
		
		echo '<li class="field">';
		echo '<label for="source_date_min" class="coltab">' . __( 'Show articles created after', 'wpcufpn' ) .
		'</label>';
		echo '<input id="source_date_min" type="text" name="wpcufpn_source_date_min" class="datepicker short-text" '.
			'value="' . htmlspecialchars( $settings['source_date_min'] ) . '" />';
		echo '</li>';	//field
		
		//TODO: externalize js
		$calendar_icon = plugins_url( 'img/calendar.jpg', dirname( __FILE__ ) );
		?>
		<script type="text/javascript">
			(function($) {
				$(document).ready(function() {

					$('.datepicker').datepicker({
						showOn: "button",
						buttonImage: "<?php echo $calendar_icon; ?>",
						buttonImageOnly: false
					});
					
				});
			})( jQuery );
		</script>
		<?php
	}
	
	
	public function displayNumberOfLinesField( $settings ) {
		/* Deactivated for now (vertical sliders) , TODO: reactivate */
		 echo '<li class="field"><label for="amount_rows" class="coltab">' . __( 'Number of rows', 'wpcufpn' ) . '</label>' .
		'<input id="amount_rows" type="text" name="wpcufpn_amount_rows" value="' . htmlspecialchars( $settings['amount_rows'] ) . '" class="short-text" /></li>';
		/* */
	}
	
	/**
	 * Adds fields of the pro plugin version to the Display&Theme admin settings tab
	 * 
	 */
	public function displayDisplayThemeCol1AddFields( $settings ) {

		if( isset($settings['crop_title']) )
			$crop_title_checked[$settings['crop_title']] = ' checked="checked"';
		
		// -block---------------------------------- //
		echo '<div class="wpcu-inner-admin-block with-title with-border">';
		echo '<h4>Title</h4>';
		echo '<ul class="fields">';
		
		/** Crop title radio button set **/
		echo '<li class="field"><label class="coltab">' . __( 'Crop title type', 'wpcufpn' ) . '</label>' .
				'<span class="radioset">' .
				'<input id="crop_title1" type="radio" name="wpcufpn_crop_title" value="0" ' . (isset($crop_title_checked[0])?$crop_title_checked[0]:'') . '/>' .
				'<label for="crop_title1">' . __('Words', 'wpcufpn') . '</label>' .
				'<input id="crop_title2" type="radio" name="wpcufpn_crop_title" value="1" ' . (isset($crop_title_checked[1])?$crop_title_checked[1]:'') . '/>' .
				'<label for="crop_title2">' . __('Chars', 'wpcufpn') . '</label>' .
				'<input id="crop_title3" type="radio" name="wpcufpn_crop_title" value="2" ' . (isset($crop_title_checked[2])?$crop_title_checked[2]:'') . '/>' .
				'<label for="crop_title3">' . __('Lines', 'wpcufpn') . '</label>' .
				'</span>';
		echo '</li>';
		
		echo '<li class="field"><label for="crop_title_len" class="coltab">' . __( 'Crop length', 'wpcufpn' ) . '</label>' .
				'<input id="crop_title_len" type="text" name="wpcufpn_crop_title_len" value="' . htmlspecialchars( isset($settings['crop_title_len'])?$settings['crop_title_len']:'' ) . '" class="short-text" /></li>';
		echo '</ul>';	//fields
		echo '</div>';	//wpcu-inner-admin-block
		// ---------------------------------------- //


		

		
		if( isset($settings['crop_text']) )
			$crop_text_checked[$settings['crop_text']] = ' checked="checked"';
		
		// -block---------------------------------- //
		echo '<div class="wpcu-inner-admin-block with-title with-border">';
		echo '<h4>Text</h4>';
		echo '<ul class="fields">';
		
		/** Crop text radio button set **/
		echo '<li class="field"><label class="coltab">' . __( 'Crop text type', 'wpcufpn' ) . '</label>' .
				'<span class="radioset">' .
				'<input id="crop_text1" type="radio" name="wpcufpn_crop_text" value="0" ' . (isset($crop_text_checked[0])?$crop_text_checked[0]:'') . '/>' .
				'<label for="crop_text1">' . __('Words', 'wpcufpn') . '</label>' .
				'<input id="crop_text2" type="radio" name="wpcufpn_crop_text" value="1" ' . (isset($crop_text_checked[1])?$crop_text_checked[1]:'') . '/>' .
				'<label for="crop_text2">' . __('Chars', 'wpcufpn') . '</label>' .
				'<input id="crop_text3" type="radio" name="wpcufpn_crop_text" value="2" ' . (isset($crop_text_checked[2])?$crop_text_checked[2]:'') . '/>' .
				'<label for="crop_text3">' . __('Lines', 'wpcufpn') . '</label>' .
				'</span>';
		echo '</li>';
		
		echo '<li class="field"><label for="crop_text_len" class="coltab">' . __( 'Crop length', 'wpcufpn' ) . '</label>' .
				'<input id="crop_text_len" type="text" name="wpcufpn_crop_text_len" value="' . htmlspecialchars( isset($settings['crop_text_len'])?$settings['crop_text_len']:'' ) . '" class="short-text" /></li>';
		echo '</ul>';	//fields
		echo '</div>';	//wpcu-inner-admin-block
		// ---------------------------------------- //

		
		
		
		if( isset($settings['autoanimation']) )
			$autoanim_checked[$settings['autoanimation']] = ' checked="checked"';
		if( isset($settings['autoanimation_trans']) )
			$transition_selected[$settings['autoanimation_trans']] = ' selected="selected"';
		
		

		
		/*
		 * 
		 * Specific parameters with Mansonry
		 * 
		 */ 
		$classdisabled="";
		if (strpos($settings["theme"],'masonry') || strpos($settings["theme"],'timeline') || strpos($settings["theme"],'smooth')){
			$classdisabled=" disabled";
		}
		
		
		// -block---------------------------------- //
		echo '<div id="wpcufpn_config_animation" class="wpcu-inner-admin-block with-title with-border '.$classdisabled.'">';
		echo '<h4>Animation</h4>';
		echo '<ul class="fields">';
		
		/** Autoanimation radio button set **/
		echo '<li class="field"><label class="coltab">' . __( 'Autoanimation', 'wpcufpn' ) . '</label>' .
				'<span class="radioset">' .
				'<input id="autoanimation1" type="radio" name="wpcufpn_autoanimation" value="0" ' . (isset($autoanim_checked[0])?$autoanim_checked[0]:'') . $classdisabled .'/>' .
				'<label for="autoanimation1">' . __('Off', 'wpcufpn') . '</label>' .
				'<input id="autoanimation2" type="radio" name="wpcufpn_autoanimation" value="1" ' . (isset($autoanim_checked[1])?$autoanim_checked[1]:'') .  $classdisabled .'/>' .
				'<label for="autoanimation2">' . __('On', 'wpcufpn') . '</label>' .
				'</span>';
		echo '</li>';
		
		/** Autoanimation transition drop-down **/
		echo '<li class="field"><label for="autoanimation_trans" class="coltab">' . __( 'Autoanimation transition', 'wpcufpn' ) . '</label>' .
				'<select id="autoanimation_trans" name="wpcufpn_autoanimation_trans"'.$classdisabled.'>';
		foreach( $this->_autoanim_trans_values as $value=>$text ) {
			echo '<option value="' . $value . '" ' . (isset($transition_selected[$value])?$transition_selected[$value]:'') . '>' .
					$text . '</option>';
		}
		echo '</select></li>';

		echo '</ul>';	//fields
		echo '</div>';	//wpcu-inner-admin-block
		// ---------------------------------------- //
		
		
		$classdisabled=" disabled";
		if (strpos($settings["theme"],'masonry') || strpos($settings["theme"],'smooth') || strpos($settings["theme"],'timeline') ){
			$classdisabled="";
		}
		
		
		
		// -block---------------------------------- //
		echo '<div id="wpcufpn_config_color" class="wpcu-inner-admin-block with-title with-border '.$classdisabled.'">';
		echo '<h4>Color</h4>';
		echo '<ul class="fields">';
		
		/** Color Picker **/
		echo '<li class="field"><label class="coltab">' . __( 'Choose Color', 'wpcufpn' ) . '</label>';
		echo '		
				<div id="colorPicker">
			        <a class="color '.$classdisabled.'"><div class="colorInner" style="background-color: ' .(isset($settings['colorpicker'])?$settings['colorpicker']:'#ff0000') . ';"></div></a>
			        <div class="track" style="display: none; background-image: none;"><canvas width="150" height="150"></canvas></div>
			        <ul class="dropdown"></ul>
			        <input id="colorpicker" type="hidden" name="wpcufpn_colorpicker" class="colorInput" value="' .(isset($settings['colorpicker'])?$settings['colorpicker']:'#ff0000') . '"/>
			    </div>
		 
		 <script type="text/javascript">
			jQuery(document).ready(function()
	        {
				var $box = jQuery("#colorPicker");
	            $box.tinycolorpicker({
	            	backgroundUrl:"'.plugins_url("/wp-latest-posts/css/images/text-color.png").'",
				});

			});
		</script>
		 ';		
		echo '</li>';		
		echo '</ul>';	//fields
		echo '</div>';	//wpcu-inner-admin-block
		// ---------------------------------------- //
		
		
		
	}
	
	/**
	 * Adds cropping feature field of the pro plugin version to the Image Source admin settings tab
	 *
	 */
	public function displayImageSourceCropAddFields( $settings ) {

		if( isset($settings['crop_img']) )
			$crop_img_checked[$settings['crop_img']] = ' checked="checked"';

		/** Crop images switch **/
		echo '<li class="field"><label class="coltab">' . __( 'Crop images to fit size', 'wpcufpn' ) . '</label>' .
				'<span class="radioset">' .
				'<input id="crop_img1" type="radio" name="wpcufpn_crop_img" value="0" ' . (isset($crop_img_checked[0])?$crop_img_checked[0]:'') . '/>' .
				'<label for="crop_img1">' . __('Off', 'wpcufpn') . '</label>' .
				'<input id="crop_img2" type="radio" name="wpcufpn_crop_img" value="1" ' . (isset($crop_img_checked[1])?$crop_img_checked[1]:'') . '/>' .
				'<label for="crop_img2">' . __('On', 'wpcufpn') . '</label>' .
				'</span>';
		echo '</li>';
		echo '</ul>';	//fields

	}
	
	public function displayAdvancedAddFields( $settings ) {

		echo '<li class="field"><label for="read_more" class="coltab">' . __( 'Read more text', 'wpcufpn' ) . '</label>' .
				'<input id="read_more" type="text" name="wpcufpn_read_more" value="' . htmlspecialchars( isset($settings['read_more'])?$settings['read_more']:'' ) . '" class="short-text" /></li>';
		
		/** Default image upload field **/
		echo '<li class="field"><label for="default_img" class="coltab">' . __( 'Default image', 'wpcufpn' ) . '</label>' .
				'<input id="default_img" type="file" name="wpcufpn_default_img" value="' . htmlspecialchars( isset($settings['default_img'])?$settings['default_img']:'' ) . '" class="regular-text" />';
		if( isset($settings['default_img']) && $settings['default_img'] )
			echo '<img class="default_preview" src="' . $settings['default_img'] .
			'" alt="' . __( 'Default image preview', 'wpcufpn' ) .
			'" title="' . __( 'Default image preview', 'wpcufpn' ) . '"/>';
		echo '<input type="hidden" id="default_img_previous" name="wpcufpn_default_img_previous" value="' . htmlspecialchars( isset($settings['default_img'])?$settings['default_img']:'' ) . '" />';
		echo '</li>';

	 }
	 
	public function displayAbout() {

		echo '<p>' . __('Pro add-on plugin version ') . $this->version . __(' is installed and activated.') . '</p>';
		echo '<p><em>' . __('Congratulations! and thank you for your support.') . '</em></p>';

	}
	
	/**
	 * Displays additional source types modes on the front-end
	 * WP Filter
	 *  
	 * @param object $widget
	 */
	public function displayFrontAdditionalSources( $html, $widget ) {

		if( 'src_tags' == $widget->settings['source_type'] ) {
			$html .= '<p>TODO: list posts by tags</p>';
			//TODO
			
		}
		return $html;
	}
	
	/**
	 * Filters front-end list display query
	 * to add additional pro feature arguments
	 *  
	 */
	public function wpcufpn_src_category_argsFilter( $args ) {

		//TODO: apply source_date_min
		
		return $args;
	}
}
?>